@@ -103,6 +103,12 @@ class ListAttributeAccessor:
             self._attribute.deserialize(item) for item in self.mapping.__getitem__(key)
         )
 
+    def __eq__(self, other):
+        return list(self) == other
+
+    def __add__(self, other):
+        return list(self) + other
+
     def append(self, item):
         self.mapping.append(self._attribute.serialize(item))
 
@@ -156,6 +162,8 @@ class ListAttribute(sheraf.attributes.Attribute):
         self.persistent_type = persistent_type
         self.accessor_type = accessor_type
         kwargs.setdefault("default", self.persistent_type)
+        kwargs["read_memoization"] = False
+        kwargs["write_memoization"] = False
         super().__init__(**kwargs)
 
     def values(self, list_):
