@@ -132,7 +132,7 @@ class BaseIndexedModel(BaseModel, metaclass=BaseIndexedModelMetaclass):
         return sheraf.queryset.QuerySet(model_class=cls)
 
     @classmethod
-    def create(cls, *args, **kwargs):
+    def create(cls, **kwargs):
         if not cls.primary_key():
             raise sheraf.exceptions.PrimaryKeyException(
                 "{} inherit from IndexedModel but has no primary key. Cannot create.".format(
@@ -140,7 +140,18 @@ class BaseIndexedModel(BaseModel, metaclass=BaseIndexedModelMetaclass):
                 )
             )
 
-        return super().create(*args, **kwargs)
+        return super().create(**kwargs)
+
+    def initialize(self, **kwargs):
+        if self.primary_key() in kwargs:
+            identifier = kwargs[self.primary_key()]
+            del kwargs[self.primary_key()]
+        else:
+            identifier = self.attributes[self.primary_key()].create(self)
+
+        self.__setattr__(self.primary_key(), identifier)
+
+        super().initialize(**kwargs)
 
     @classmethod
     def _check_args(cls, *args, **kwargs):
@@ -404,11 +415,15 @@ class BaseIndexedModel(BaseModel, metaclass=BaseIndexedModelMetaclass):
         return cls.filter(*args, **kwargs).get()
 
     def __repr__(self):
-        identifier = (
-            self.identifier
-            if self.mapping is not None and self.primary_key() in self.mapping
-            else None
-        )
+        try:
+            identifier = (
+                self.identifier
+                if self.mapping is not None and self.primary_key() in self.mapping
+                else None
+            )
+        except:
+            identifier = "???"
+
         return "<{} {}={}>".format(
             self.__class__.__name__, self.primary_key(), identifier
         )
@@ -426,12 +441,22 @@ class BaseIndexedModel(BaseModel, metaclass=BaseIndexedModelMetaclass):
     def __setattr__(self, name, value):
         attribute = self.attributes.get(name)
         if attribute:
+            was_created = attribute.is_created(self)
+            if was_created:
+                prev_value = getattr(self, name)
             old_values = self.before_index_edition(attribute)
 
         super().__setattr__(name, value)
 
         if attribute:
-            self.after_index_edition(attribute, old_values)
+            try:
+                self.after_index_edition(attribute, old_values)
+            except sheraf.SherafException:
+                if not was_created:
+                    super().__delattr__(name)
+                else:
+                    super().__setattr__(name, prev_value)
+                raise
 
     def __delattr__(self, name):
         attribute = self.attributes.get(name)
@@ -538,11 +563,8 @@ class BaseIndexedModel(BaseModel, metaclass=BaseIndexedModelMetaclass):
             ...
         sheraf.exceptions.ModelObjectNotFoundException: Id '...' not found in MyModel
         """
-        for index in self.indexes.values():
-            index.delete_item(self)
-
-        for attr in self.attributes.values():
-            attr.delete(self)
+        for attr_name in self.attributes.keys():
+            delattr(self, attr_name)
 
     @classmethod
     def count(cls, index_name=None):
